@@ -735,6 +735,51 @@ def pg_shovel(cnxn, tbl_source, tbl_destination, fields_in, fields_out=False,
         return False
 
 
+def pg_dteload(cnxn, handle, table_name):
+    """Uses psycopg2 methods to load DaysToEvent data from a csv file into a database table.
+
+    Uses default schema; no support for specifying schema inside this function.
+
+    Returns the name of the created table. Any check of the COPY'd count versus the handle length will have to take place elsewhere.
+
+    Parameters
+    ==========
+    cnxn: required
+        Must be a connection created by psycopg2.connect().
+    
+    handle: required
+        Must be a file-like object. I.e., returned by open(path).
+    
+    table_name: required
+        Table name for the load.
+    """
+    
+    try:
+        import psycopg2
+    except ImportError:
+        raise ImportError("The pg_dteload() function requires psycopg2 to be installed.")
+    
+    # acquire a cursor from the connection object
+    cursor = cnxn.cursor()
+    
+    table_create_sql = 'CREATE TABLE IF NOT EXISTS %s (key BIGINT, visitlink BIGINT, daystoevent BIGINT);' % table_name
+    cursor.execute(table_create_sql)
+    cnxn.commit()
+    
+    cp_sql = "COPY %s FROM STDIN DELIMITER ',' CSV HEADER;" % (table_name)
+    cursor.copy_expert(cp_sql, handle)
+    cnxn.commit()
+    
+    count_sql = "SELECT COUNT(*) FROM %s LIMIT 1;" % (table_name)
+    cursor.execute(count_sql)
+    result = cursor.fetchone()
+    rowcount = int(result[0])
+    
+    cursor = None
+    
+    return (table_name, rowcount)
+
+
 def pg_drop(cnxn, tbl_name):
     cursor = cnxn.cursor()
     stmt = 'DROP TABLE IF EXISTS %s;' % tbl_name
